# Global variables
utils::globalVariables(c(".shinyMerPar", "sig", "sigma", "Lind", "group"))

#' @importFrom methods as
#' @importFrom stats AIC as.formula formula logLik median model.matrix na.omit
#' pnorm qnorm quantile residuals rgamma rnorm sd vcov weighted.mean delete.response
#' model.frame na.pass reformulate runif terms getCall
#' @importFrom utils packageVersion
zzz <- function(){
  # Nothing

}
